@@ -5,11 +5,20 @@ import json
 import re
 
 from lxml import etree
-from PyQt5.QtCore import (QByteArray, QCoreApplication, QSettings, QThread,
-                          QTimer, pyqtSignal)
+from PyQt5.QtCore import (
+    QByteArray, QCoreApplication, QSettings, QThread,
+    QTimer, pyqtSignal, Qt
+)
 from PyQt5.QtGui import QIcon
-from PyQt5.QtWidgets import (QDialog, QHBoxLayout, QLabel, QLineEdit,
-                             QListWidget, QPushButton, QVBoxLayout)
+from PyQt5.QtWidgets import (
+    QDialog, QHBoxLayout, QLabel, QLineEdit,
+    QListWidget, QPushButton, QVBoxLayout, QCompleter
+)
+
+try:
+    import owm_cities
+except ImportError:
+    from meteo_qt import owm_cities
 
 
 class SearchCity(QDialog):
@@ -28,7 +37,10 @@ class SearchCity(QDialog):
         self.layout = QVBoxLayout()
         self.lineLayout = QHBoxLayout()
         self.buttonSearch = QPushButton()
-        self.buttonSearch.setIcon(QIcon(':/find'))
+        icon = QIcon.fromTheme('system-search')
+        if icon.isNull():
+            icon = QIcon(':/find')
+        self.buttonSearch.setIcon(icon)
         self.buttonSearch.setToolTip(
             QCoreApplication.translate(
                 'Search city button Tooltip',
@@ -38,7 +50,10 @@ class SearchCity(QDialog):
         )
         self.buttonSearch.clicked.connect(self.search)
         self.buttonMyLocation = QPushButton()
-        self.buttonMyLocation.setIcon(QIcon(':/mylocation'))
+        icon = QIcon.fromTheme('network-wireless')
+        if icon.isNull():
+            icon = QIcon(':/mylocation')
+        self.buttonMyLocation.setIcon(icon)
         self.buttonMyLocation.setToolTip(
             QCoreApplication.translate(
                 'Search by geolocalisation button tooltip',
@@ -50,12 +65,18 @@ class SearchCity(QDialog):
         self.line_search = QLineEdit(
             QCoreApplication.translate(
                 'Search city dialogue',
-                'Start typing the city or the geographic '
+                'Start typing the city or the ID or the geographic '
                 'coordinates "latitude, longitude"',
                 'Default message in the search field'
             )
         )
         self.line_search.selectAll()
+
+        completer = QCompleter(owm_cities.cities_list, self)
+        completer.setCaseSensitivity(Qt.CaseInsensitive)
+        self.line_search.setCompleter(completer)
+        self.line_search.setClearButtonEnabled(True)
+
         self.listWidget = QListWidget()
         self.status = QLabel()
         self.lineLayout.addWidget(self.line_search)
@@ -102,6 +123,14 @@ class SearchCity(QDialog):
 
     def timer_run(self):
         self.timer_search.start(1000)
+        self.status.setText(
+            "ℹ "
+            + QCoreApplication.translate(
+                "Status message",
+                "Put the city's name, comma, 2-letter country code (ex: London, GB)",
+                "City search dialogue"
+            )
+        )
 
     def closeEvent(self, event):
         self.settings.setValue(
@@ -188,9 +217,11 @@ class SearchCity(QDialog):
 
     def search(self):
         self.timer_search.stop()
-        self.city = (self.line_search.text())
+        city = self.line_search.text().strip()
         self.thread_terminate()
-        if len(self.city) < 3:
+        if len(city) == 0:
+            return
+        if len(city) < 3:
             self.status.setText(
                 QCoreApplication.translate(
                     'SearchCity window',
@@ -205,7 +236,7 @@ class SearchCity(QDialog):
         self.buttonOk.setEnabled(False)
         self.listWidget.clear()
         self.status.setText(self.search_string)
-        self.workThread = WorkThread(self.accurate_url, self.city, self.suffix)
+        self.workThread = WorkThread(self.accurate_url, city, self.suffix)
         self.workThread.setTerminationEnabled(True)
         self.workThread.city_signal['QString'].connect(self.addlist)
         self.workThread.finished.connect(self.result)
@@ -268,7 +299,12 @@ class WorkThread(QThread):
     def __init__(self, accurate_url, city, suffix, parent=None):
         QThread.__init__(self, parent)
         self.accurate_url = accurate_url
-        self.city = city
+        if city.count(',') == 1:
+            ccity = city.split(',')[0]
+            ccode = city.split(',')[1]
+            self.city = ccity + ',' + ccode.upper()
+        else:
+            self.city = city
         self.suffix = suffix
         self.tentatives = 1
         self.settings = QSettings()
@@ -281,6 +317,11 @@ class WorkThread(QThread):
         except (ValueError, IndexError) as e:
             logging.debug('Cannot find geographic coordinates' + str(e))
             logging.debug('Search by city name' + str(self.city))
+        self.search_by_id = False
+        if self.city.isdecimal():
+            self.accurate_url = self.accurate_url.replace('find?q=', 'weather?id=')
+            self.search_by_id = True
+            logging.debug('Search city by ID')
 
     def run(self):
         use_proxy = self.settings.value('Proxy') or 'False'
@@ -327,7 +368,7 @@ class WorkThread(QThread):
                 + self.suffix
             )
             logging.debug(
-                'City before utf8 encode :' + self.accurate_url
+                'City before utf8 encode: ' + self.accurate_url
                 + self.city + self.suffix
             )
             req = urllib.request.urlopen(
@@ -366,46 +407,78 @@ class WorkThread(QThread):
                 logging.debug('Tries: ' + str(self.tentatives))
                 self.run()
         # No result
-        try:
-            if int(tree[1].text) == 0:
-                logging.debug('Number of cities: 0')
-                if self.tentatives == 10:
+        if self.search_by_id is False:
+            try:
+                if int(tree[1].text) == 0:
+                    logging.debug('Number of cities: 0')
+                    if self.tentatives == 10:
+                        return
+                    else:
+                        self.tentatives += 1
+                        logging.debug('Tries: ' + str(self.tentatives))
+                        logging.debug('Try to retreive city information...')
+                        self.run()
+            except:
+                return
+
+            for i in range(int(tree[1].text)):
+                city = tree[3][i][0].get('name')
+                country = tree[3][i][0][1].text
+                if country is None:
+                    country = ''
+                id_ = tree[3][i][0].get('id')
+                lon = tree[3][i][0][0].get('lon')
+                lat = tree[3][i][0][0].get('lat')
+                if int(id_) == 0:
+                    logging.error('Error ID: ' + str(id_))
+                    if self.tentatives == 10:
+                        self.error['QString'].emit(error_message)
+                        return
+                    else:
+                        self.tentatives += 1
+                        logging.debug('Tries: ' + str(self.tentatives))
+                        logging.debug('Try to retrieve city information...')
+                        # Try with a fuzzy city name
+                        if city != '':
+                            logging.info('Change search to:' + city)
+                            self.city = (
+                                repr(city.encode('utf-8'))
+                                .replace("b'", "")
+                                .replace("\\x", "%")
+                                .replace("'", "")
+                                .replace(' ', '%20')
+                            )
+                        self.run()
+                if city == '':
+                    if self.tentatives == 10:
+                        self.error['QString'].emit(error_message)
+                        return
+                    else:
+                        self.tentatives += 1
+                        logging.debug('Tries: ' + str(self.tentatives))
+                        logging.debug('Try to retrieve city information...')
+                        self.run()
+                try:
+                    if id_ == '0':
+                        continue
+
+                    place = f'{id_} - {city} - {country} - {lat}° , {lon}°'
+
+                    if place in self.lista:
+                        continue
+                    self.lista.append(place)
+                except:
+                    logging.critical('An error has occured:')
+                    logging.critical('ID' + str(id_))
+                    logging.critical('City' + str(city))
+                    logging.critical('Country' + str(country))
                     return
-                else:
-                    self.tentatives += 1
-                    logging.debug('Tries: ' + str(self.tentatives))
-                    logging.debug('Try to retreive city information...')
-                    self.run()
-        except:
-            return
-        for i in range(int(tree[1].text)):
-            city = tree[3][i][0].get('name')
-            country = tree[3][i][0][1].text
-            if country is None:
-                country = ''
-            id_ = tree[3][i][0].get('id')
-            lon = tree[3][i][0][0].get('lon')
-            lat = tree[3][i][0][0].get('lat')
-            if int(id_) == 0:
-                logging.error('Error ID: ' + str(id_))
-                if self.tentatives == 10:
-                    self.error['QString'].emit(error_message)
-                    return
-                else:
-                    self.tentatives += 1
-                    logging.debug('Tries: ' + str(self.tentatives))
-                    logging.debug('Try to retrieve city information...')
-                    # Try with a fuzzy city name
-                    if city != '':
-                        logging.info('Change search to:' + city)
-                        self.city = (
-                            repr(city.encode('utf-8'))
-                            .replace("b'", "")
-                            .replace("\\x", "%")
-                            .replace("'", "")
-                            .replace(' ', '%20')
-                        )
-                    self.run()
+        else:
+            try:
+                city = tree[0].get('name')
+            except UnboundLocalError:
+                logging.debug(f"Could'nt find any city with the ID {self.city}")
+                return
             if city == '':
                 if self.tentatives == 10:
                     self.error['QString'].emit(error_message)
@@ -415,25 +488,26 @@ class WorkThread(QThread):
                     logging.debug('Tries: ' + str(self.tentatives))
                     logging.debug('Try to retrieve city information...')
                     self.run()
-            try:
-                if id_ == '0':
-                    continue
+            country = tree[0][1].text
+            if country is None:
+                country = ''
+            id_ = tree[0].get('id')
+            lon = tree[0][0].get('lon')
+            lat = tree[0][0].get('lat')
+            place = (
+                id_
+                + ' - '
+                + city
+                + ' - '
+                + country
+                + ' - '
+                + ' {0}° '
+                + '-'
+                + ' {1}°'
+            ).format(lat, lon)
+            self.lista.append(place)
 
-                place = (
-                    id_ + ' - ' + city + ' - ' + country + ' - ' +
-                    ' {0}°' + '-' + ' {1}°'
-                ).format(lat, lon)
 
-                if place in self.lista:
-                    continue
-                self.lista.append(place)
-            except:
-                logging.critical('An error has occured:')
-                logging.critical('ID' + str(id_))
-                logging.critical('City' + str(city))
-                logging.critical('Country' + str(country))
-                return
         for i in self.lista:
             self.city_signal['QString'].emit(i)
         logging.debug('City thread done')
-        return
