@@ -1,13 +1,16 @@
 import logging
 import os
+import glob
 
-from PyQt5.QtCore import (QCoreApplication, QLocale, QSettings, QSize, Qt,
-                          pyqtSignal)
+from PyQt5.QtCore import (
+    QCoreApplication, QLocale, QSettings, QSize, Qt, pyqtSignal
+)
 from PyQt5.QtGui import QIcon
-from PyQt5.QtWidgets import (QCheckBox, QColorDialog, QComboBox, QDialog,
-                             QDialogButtonBox, QGridLayout, QHBoxLayout,
-                             QLabel, QLineEdit, QPushButton, QSpinBox,
-                             QVBoxLayout)
+from PyQt5.QtWidgets import (
+    QCheckBox, QColorDialog, QComboBox, QDialog, QDialogButtonBox,
+    QGridLayout, QHBoxLayout, QLabel, QLineEdit, QPushButton, QSpinBox,
+    QVBoxLayout
+)
 
 try:
     import citylistdlg
@@ -59,35 +62,37 @@ class MeteoSettings(QDialog):
                 'Settings dialogue'
             )
         )
-        self.language_dico = {'bg': self.tr('Bulgarian'),
-                              'ca': self.tr('Catalan'),
-                              'cs': self.tr('Czech'),
-                              'da': self.tr('Danish'),
-                              'de': self.tr('German'),
-                              'el': self.tr('Greek'),
-                              'en': self.tr('English'),
-                              'es': self.tr('Spanish'),
-                              'fi': self.tr('Finnish'),
-                              'fr': self.tr('French'),
-                              'he': self.tr('Hebrew'),
-                              'hr': self.tr('Croatian'),
-                              'hu': self.tr('Hungarian'),
-                              'it': self.tr('Italian'),
-                              'ja': self.tr('Japanese'),
-                              'lt': self.tr('Lithuanian'),
-                              'nb': self.tr('Norwegian (Bokmaal)'),
-                              'nl': self.tr('Dutch'),
-                              'pl': self.tr('Polish'),
-                              'pt': self.tr('Portuguese'),
-                              'pt_BR': self.tr('Brazil Portuguese'),
-                              'ro': self.tr('Romanian'),
-                              'ru': self.tr('Russian'),
-                              'sk': self.tr('Slovak'),
-                              'sv': self.tr('Swedish'),
-                              'tr': self.tr('Turkish'),
-                              'uk': self.tr('Ukrainian'),
-                              'zh_TW': self.tr('Chinese Traditional'),
-                              'zh_CN': self.tr('Chinese Simplified')}
+        self.language_dico = {
+            'bg': self.tr('Bulgarian'),
+            'ca': self.tr('Catalan'),
+            'cs': self.tr('Czech'),
+            'da': self.tr('Danish'),
+            'de': self.tr('German'),
+            'el': self.tr('Greek'),
+            'en': self.tr('English'),
+            'es': self.tr('Spanish'),
+            'fi': self.tr('Finnish'),
+            'fr': self.tr('French'),
+            'he': self.tr('Hebrew'),
+            'hr': self.tr('Croatian'),
+            'hu': self.tr('Hungarian'),
+            'it': self.tr('Italian'),
+            'ja': self.tr('Japanese'),
+            'lt': self.tr('Lithuanian'),
+            'nb': self.tr('Norwegian (Bokmaal)'),
+            'nl': self.tr('Dutch'),
+            'pl': self.tr('Polish'),
+            'pt': self.tr('Portuguese'),
+            'pt_BR': self.tr('Brazil Portuguese'),
+            'ro': self.tr('Romanian'),
+            'ru': self.tr('Russian'),
+            'sk': self.tr('Slovak'),
+            'sv': self.tr('Swedish'),
+            'tr': self.tr('Turkish'),
+            'uk': self.tr('Ukrainian'),
+            'zh_TW': self.tr('Chinese Traditional'),
+            'zh_CN': self.tr('Chinese Simplified')
+        }
         lang_list = sorted(self.language_dico.values())
         # English as fallback language
         if locale not in self.language_dico:
@@ -113,24 +118,57 @@ class MeteoSettings(QDialog):
         self.units_combo.setCurrentIndex(self.units_combo.findText(
             self.units_dico[self.temp_unit]))
         self.units_combo.currentIndexChanged.connect(self.units)
-        # Beaufort
-        self.bft_checkbox = QCheckBox(
+        # Wind unit
+        self.wind_unit_changed = False
+        self.wind_unit = self.settings.value('Wind_unit')
+        if self.wind_unit is None or self.wind_unit == '':
+            self.wind_unit = 'df'
+            self.wind_unit_changed = True
+        self.wind_unit_label = QLabel(
             QCoreApplication.translate(
-                'Wind unit - Checkbox label',
-                'Wind unit in Beaufort',
+                'Label of the checkbox',
+                'Wind speed unit',
                 'Settings dialogue'
             )
         )
-        bft_bool = self.settings.value('Beaufort') or 'False'
-        self.bft_bool = eval(bft_bool)
-        self.bft_checkbox.setChecked(self.bft_bool)
-        self.bft_checkbox.stateChanged.connect(self.beaufort)
-        self.bft_changed = False
+        self.wind_unit_combo = QComboBox()
+        wind_units_list = [
+            QCoreApplication.translate(
+                'Option to choose the default wind speed unit',
+                'Default',
+                'Settings diaogue'
+            ),
+            QCoreApplication.translate(
+                'Option to choose wind speed unit',
+                'Beaufort',
+                'Settings dialogue'
+            ),
+            QCoreApplication.translate(
+                'Option to choose wind speed unit',
+                'Km/h',
+                'Settings dialogue'
+            )
+        ]
+        self.wind_unit_dico = {
+            'df': wind_units_list[0],
+            'bf': wind_units_list[1],
+            'km': wind_units_list[2]
+        }
+
+        self.wind_unit_combo.addItems(wind_units_list)
+        self.wind_unit_combo.setCurrentIndex(
+            self.wind_unit_combo.findText(self.wind_unit_dico[self.wind_unit])
+        )
+        self.wind_unit_combo.currentIndexChanged.connect(self.wind_unit_change_apply)
+        self.wind_unit_combo.model().item(2).setEnabled(False)
+        if self.temp_unit == 'metric':
+            self.wind_unit_combo.model().item(2).setEnabled(True)
         # Decimal in trayicon
         self.temp_decimal_label = QLabel(
             QCoreApplication.translate(
                 'If the temperature will be shown with a decimal or rounded in tray icon',
-                'Temperature accuracy in system tray', 'Settings dialogue'
+                'Temperature accuracy in system tray',
+                'Settings dialogue'
             )
         )
         self.temp_decimal_combo = QComboBox()
@@ -199,34 +237,132 @@ class MeteoSettings(QDialog):
         self.notifier_checkbox.stateChanged.connect(self.notifier)
         self.notifier_changed = False
         # Icon & Temp
-        self.tray_icon_temp_label = QLabel(QCoreApplication.translate(
-            "Settings dialogue", "System tray icon",
-            '''Setting to choose the type of the icon on the tray (only icon,
-            only text, icon&text'''))
+        self.tray_icon_temp_label = QLabel(
+            QCoreApplication.translate(
+                'Settings dialogue',
+                'System tray icon',
+                'Setting to choose the type of the icon on the tray'
+                '(only icon only text, icon&text'
+            )
+        )
         self.tray_icon_combo = QComboBox()
         tray_icon_temp = QCoreApplication.translate(
-            "Settings dialogue", "Icon & temperature",
-            'Setting to choose the type of the icon on the tray')
+            'Settings dialogue',
+            'Icon & temperature',
+            'Setting to choose the type of the icon on the tray'
+        )
         tray_icon = QCoreApplication.translate(
-            "Settings dialogue", "Icon",
-            'Setting to choose the type of the icon on the tray')
+            'Settings dialogue',
+            'Icon',
+            'Setting to choose the type of the icon on the tray'
+        )
         tray_temp = QCoreApplication.translate(
-            "Settings dialogue", "Temperature",
-            'Setting to choose the type of the icon on the tray')
-        self.tray_dico = {'icon&temp': tray_icon_temp, 'icon': tray_icon,
-                          'temp': tray_temp}
+            'Settings dialogue',
+            'Temperature',
+            'Setting to choose the type of the icon on the tray'
+        )
+        tray_icon_feels_like = QCoreApplication.translate(
+            'Settings dialogue',
+            'Icon & Feels like temperature',
+            'Setting to choose the type of the icon on the tray'
+        )
+        tray_feels_like = QCoreApplication.translate(
+            'Settings dialogue',
+            'Feels like temperature',
+            'Setting to choose the type of the icon on the tray'
+        )
+        self.tray_dico = {
+            'icon&temp': tray_icon_temp,
+            'icon': tray_icon,
+            'temp': tray_temp,
+            'icon&feels_like': tray_icon_feels_like,
+            'feels_like_temp': tray_feels_like,
+        }
         set_tray_icon = self.settings.value('TrayType') or 'icon&temp'
         tray_icon_list = sorted(self.tray_dico.values())
         self.tray_icon_combo.addItems(tray_icon_list)
-        self.tray_icon_combo.setCurrentIndex(self.tray_icon_combo.findText
-                                             (self.tray_dico[set_tray_icon]))
+        self.tray_icon_combo.setCurrentIndex(
+            self.tray_icon_combo.findText(self.tray_dico[set_tray_icon])
+        )
         self.tray_icon_combo.currentIndexChanged.connect(self.tray)
         self.tray_changed = False
+        # Weather icons
+        self.comboBox_icons_theme = QComboBox()
+        thema_list = ['OpenWeatherMap']
+        self.system_default_theme_translated = {
+            'System default': QCoreApplication.translate(
+                'Settings dialogue',
+                'System default',
+                'ComboBox to choose the system default icons theme'
+            )
+        }
+        self.comboBox_icons_theme.setToolTip(
+            QCoreApplication.translate(
+                'Settings dialogue',
+                'Icons theme',
+                'Tooltip of the ComboBox to choose the icons theme'
+            )
+        )
+        thema_list.append(self.system_default_theme_translated['System default'])
+        logging.debug('Icons theme paths : ' + str(QIcon.themeSearchPaths()))
+        for themedir in QIcon.themeSearchPaths():
+            for dirpath in glob.glob(themedir + '/*/'):
+                for path in glob.glob(dirpath + '/*'):
+                    if path.count('index.theme'):
+                        thema = os.path.basename(os.path.dirname(path))
+                        if thema not in thema_list:
+                            thema_list.append(thema)
+
+        thema_list = sorted(thema_list, key=str.casefold)
+        logging.debug('Found themes : ' + str(thema_list))
+        self.comboBox_icons_theme.addItems(thema_list)
+
+        icontheme_conf = self.settings.value('IconsTheme') or 'System default'
+        if icontheme_conf == 'System default':
+            self.comboBox_icons_theme.setCurrentIndex(
+                self.comboBox_icons_theme.findText(self.system_default_theme_translated['System default'])
+            )
+        else:
+            self.comboBox_icons_theme.setCurrentIndex(
+                self.comboBox_icons_theme.findText(icontheme_conf)
+            )
+
+        self.comboBox_icons_theme.currentIndexChanged.connect(self.system_theme_icons)
+        self.comboBox_icons_theme_changed = False
+
+        # Toggle icon Temp
+        self.toggle_tray_label = QLabel(
+            QCoreApplication.translate(
+                'Settings dialogue',
+                'Toggle tray icon interval',
+                'Label for the option of the checkbox to '
+                'activate the toggle of the tray icon and temperature'
+            )
+        )
+        toggle_interval = self.settings.value('Toggle_tray_interval') or '0'
+        self.toggle_tray_spinbox = QSpinBox()
+        self.toggle_tray_spinbox.setRange(0, 100000)
+        self.toggle_tray_spinbox_changed = False
+        self.toggle_tray_spinbox.valueChanged.connect(self.toggle_tray_interval_change)
+        self.toggle_tray_spinbox.setValue(int(toggle_interval))
+        self.toggle_tray_interval_label = QLabel(
+            QCoreApplication.translate(
+                'Settings dialogue',
+                'seconds. Set to 0 to deactivate',
+                'Label after the spinbox to choose the interval '
+                'to toggle the tray icon and temperature'
+            )
+        )
+        self.activate_toggle_check()
         # Font size
         fontsize = self.settings.value('FontSize') or '18'
-        self.fontsize_label = QLabel(QCoreApplication.translate(
-            "Settings dialog", "Font size in tray",
-            "Setting for the font size of the temperature in the tray icon"))
+        self.fontsize_label = QLabel(
+            QCoreApplication.translate(
+                'Settings dialogue',
+                'Font size in tray',
+                'Setting for the font size of the temperature in the tray icon'
+            )
+        )
         self.fontsize_spinbox = QSpinBox()
         self.fontsize_spinbox.setRange(12, 32)
         self.fontsize_spinbox.setValue(int(fontsize))
@@ -286,10 +422,42 @@ class MeteoSettings(QDialog):
             )
         )
         self.owmkey_create.setOpenExternalLinks(True)
-        apikey = self.settings.value('APPID') or ''
+        apikey = self.settings.value('APPID') or 'df1cc7dcbb602dbc33835dd2b89a3504'
         self.owmkey_text = QLineEdit()
         self.owmkey_text.setText(apikey)
         self.owmkey_text.textChanged.connect(self.apikey_changed)
+
+        self.start_minimized_label = QLabel(
+            QCoreApplication.translate(
+                'Checkable option to show or not the window at startup',
+                'Start minimized',
+                'Settings dialogue'
+            )
+        )
+        self.start_minimized_chbx = QCheckBox()
+        start_minimized_bool = self.settings.value('StartMinimized') or 'True'
+        self.start_minimized_bool = eval(start_minimized_bool)
+        self.start_minimized_chbx.setChecked(self.start_minimized_bool)
+        self.start_minimized_chbx.stateChanged.connect(self.start_minimized)
+        self.start_minimized_changed = False
+
+        self.logging_label = QLabel(
+            QCoreApplication.translate(
+                'Option for logging level',
+                'Logging level',
+                'Settings window'
+            )
+        )
+        self.logging_level_combo = QComboBox()
+        logging_levels = ['CRITICAL', 'ERROR', 'WARNING', 'INFO', 'DEBUG']
+        self.logging_level_combo.addItems(logging_levels)
+        level = self.settings.value('Logging/Level') or 'INFO'
+        self.logging_level_combo.setCurrentIndex(
+            self.logging_level_combo.findText(level)
+        )
+        self.logging_level_combo.currentIndexChanged.connect(self.logging_set)
+        self.logging_changed = False
+
         # ----------
         self.panel = QGridLayout()
         self.panel.addWidget(self.city_title, 0, 0)
@@ -299,30 +467,39 @@ class MeteoSettings(QDialog):
         self.panel.addWidget(self.language_combo, 1, 1)
         self.panel.addWidget(self.units_label, 2, 0)
         self.panel.addWidget(self.units_combo, 2, 1)
-        self.panel.addWidget(self.bft_checkbox, 2, 2)
-        self.panel.addWidget(self.temp_decimal_label, 3, 0)
-        self.panel.addWidget(self.temp_decimal_combo, 3, 1)
-        self.panel.addWidget(self.interval_label, 4, 0)
-        self.panel.addWidget(self.interval_combo, 4, 1)
-        self.panel.addWidget(self.interval_min, 4, 2)
-        self.panel.addWidget(self.autostart_label, 5, 0)
-        self.panel.addWidget(self.autostart_checkbox, 5, 1)
-        self.panel.addWidget(self.temp_colorLabel, 6, 0)
-        self.panel.addWidget(self.temp_colorButton, 6, 1)
-        self.panel.addWidget(self.temp_color_resetButton, 6, 2)
-        self.panel.addWidget(self.notifier_label, 7, 0)
-        self.panel.addWidget(self.notifier_checkbox, 7, 1)
-        self.panel.addWidget(self.tray_icon_temp_label, 8, 0)
-        self.panel.addWidget(self.tray_icon_combo, 8, 1)
-        self.panel.addWidget(self.fontsize_label, 9, 0)
-        self.panel.addWidget(self.fontsize_spinbox, 9, 1)
-        self.panel.addWidget(self.bold_checkbox, 9, 2)
-        self.panel.addWidget(self.proxy_label, 10, 0)
-        self.panel.addWidget(self.proxy_chbox, 10, 1)
-        self.panel.addWidget(self.proxy_button, 10, 2)
-        self.panel.addWidget(self.owmkey_label, 11, 0)
-        self.panel.addWidget(self.owmkey_text, 11, 1)
-        self.panel.addWidget(self.owmkey_create, 11, 2)
+        self.panel.addWidget(self.wind_unit_label, 3, 0)
+        self.panel.addWidget(self.wind_unit_combo, 3, 1)
+        self.panel.addWidget(self.temp_decimal_label, 4, 0)
+        self.panel.addWidget(self.temp_decimal_combo, 4, 1)
+        self.panel.addWidget(self.interval_label, 5, 0)
+        self.panel.addWidget(self.interval_combo, 5, 1)
+        self.panel.addWidget(self.interval_min, 5, 2)
+        self.panel.addWidget(self.autostart_label, 6, 0)
+        self.panel.addWidget(self.autostart_checkbox, 6, 1)
+        self.panel.addWidget(self.temp_colorLabel, 7, 0)
+        self.panel.addWidget(self.temp_colorButton, 7, 1)
+        self.panel.addWidget(self.temp_color_resetButton, 7, 2)
+        self.panel.addWidget(self.notifier_label, 8, 0)
+        self.panel.addWidget(self.notifier_checkbox, 8, 1)
+        self.panel.addWidget(self.tray_icon_temp_label, 9, 0)
+        self.panel.addWidget(self.tray_icon_combo, 9, 1)
+        self.panel.addWidget(self.comboBox_icons_theme, 9, 2)
+        self.panel.addWidget(self.toggle_tray_label, 10, 0)
+        self.panel.addWidget(self.toggle_tray_spinbox, 10, 1)
+        self.panel.addWidget(self.toggle_tray_interval_label, 10, 2)
+        self.panel.addWidget(self.fontsize_label, 11, 0)
+        self.panel.addWidget(self.fontsize_spinbox, 11, 1)
+        self.panel.addWidget(self.bold_checkbox, 11, 2)
+        self.panel.addWidget(self.proxy_label, 12, 0)
+        self.panel.addWidget(self.proxy_chbox, 12, 1)
+        self.panel.addWidget(self.proxy_button, 12, 2)
+        self.panel.addWidget(self.owmkey_label, 13, 0)
+        self.panel.addWidget(self.owmkey_text, 13, 1)
+        self.panel.addWidget(self.owmkey_create, 13, 2)
+        self.panel.addWidget(self.start_minimized_label, 14, 0)
+        self.panel.addWidget(self.start_minimized_chbx, 14, 1)
+        self.panel.addWidget(self.logging_label, 15, 0)
+        self.panel.addWidget(self.logging_level_combo, 15, 1)
 
         self.layout.addLayout(self.panel)
         self.layout.addLayout(self.buttonLayout)
@@ -341,9 +518,29 @@ class MeteoSettings(QDialog):
         self.setLayout(self.layout)
         self.setWindowTitle(self.tr('Meteo-qt Configuration'))
 
+    def wind_unit_change_apply(self):
+        self.buttonBox.button(QDialogButtonBox.Apply).setEnabled(True)
+        self.wind_unit_changed = True
+
     def units(self):
         self.buttonBox.button(QDialogButtonBox.Apply).setEnabled(True)
         self.units_changed = True
+        unit = self.units_combo.currentText()
+        setUnit = [
+            key for key, value in self.units_dico.items() if value == unit
+        ]
+        if setUnit[0] == 'metric':
+            self.wind_unit_combo.model().item(2).setEnabled(True)
+        else:
+            self.wind_unit_combo.model().item(2).setEnabled(False)
+            wind = self.wind_unit_combo.currentText()
+            setWind = [
+                key for key, value in self.wind_unit_dico.items() if value == wind
+            ]
+            if setWind[0] == 'km':
+                self.wind_unit_combo.setCurrentIndex(
+                    self.wind_unit_combo.findText(self.wind_unit_dico['df'])
+                )
 
     def language(self):
         self.buttonBox.button(QDialogButtonBox.Apply).setEnabled(True)
@@ -423,12 +620,14 @@ class MeteoSettings(QDialog):
         home = os.getenv('HOME')
         total_path = home + dir_auto + d_file
         if self.autostart_state == 2:
-            desktop_file = ['[Desktop Entry]\n',
-                            'Exec=meteo-qt\n',
-                            'Name=meteo-qt\n',
-                            'Type=Application\n',
-                            'Version=1.0\n',
-                            'X-LXQt-Need-Tray=true\n']
+            desktop_file = [
+                '[Desktop Entry]\n',
+                'Exec=meteo-qt\n',
+                'Name=meteo-qt\n',
+                'Type=Application\n',
+                'Version=1.0\n',
+                'X-LXQt-Need-Tray=true\n'
+            ]
             if not os.path.exists(home + dir_auto):
                 os.system('mkdir -p {}'.format(os.path.dirname(total_path)))
             with open(total_path, 'w') as out_file:
@@ -447,7 +646,8 @@ class MeteoSettings(QDialog):
         col = QColorDialog.getColor()
         if col.isValid():
             self.temp_colorButton.setStyleSheet(
-                'QWidget {{ background-color: {0} }}'.format(col.name()))
+                'QWidget {{ background-color: {0} }}'.format(col.name())
+            )
             # focus to next elem to show immediatley the colour
             # in the button (in some DEs)
             self.temp_color_resetButton.setFocus()
@@ -479,9 +679,19 @@ class MeteoSettings(QDialog):
         self.temp_decimal_changed = True
         self.buttonBox.button(QDialogButtonBox.Apply).setEnabled(True)
 
+    def activate_toggle_check(self):
+        current_tray_option = self.tray_icon_combo.currentText()
+        for key, value in self.tray_dico.items():
+            if value == current_tray_option:
+                if key == 'icon&temp' or key == 'icon&feels_like':
+                    self.toggle_tray_spinbox.setEnabled(True)
+                else:
+                    self.toggle_tray_spinbox.setEnabled(False)
+
     def tray(self):
         self.buttonBox.button(QDialogButtonBox.Apply).setEnabled(True)
         self.tray_changed = True
+        self.activate_toggle_check()
 
     def tray_apply(self):
         tray = self.tray_icon_combo.currentText()
@@ -492,6 +702,14 @@ class MeteoSettings(QDialog):
         ]
         self.settings.setValue('TrayType', settray[0])
 
+    def toggle_tray_interval_change(self, interval):
+        self.toggle_tray_spinbox_changed = True
+        self.toggle_tray_interval = interval
+        self.buttonBox.button(QDialogButtonBox.Apply).setEnabled(True)
+
+    def toggle_tray_interval_apply(self):
+        self.settings.setValue('Toggle_tray_interval', str(self.toggle_tray_interval))
+
     def fontsize_change(self, size):
         self.fontsize_changed = True
         self.fontsize_value = size
@@ -501,6 +719,16 @@ class MeteoSettings(QDialog):
         logging.debug('Apply fontsize: ' + str(self.fontsize_value))
         self.settings.setValue('FontSize', str(self.fontsize_value))
 
+    def system_theme_icons(self):
+        self.comboBox_icons_theme_changed = True
+        self.buttonBox.button(QDialogButtonBox.Apply).setEnabled(True)
+
+    def system_icontheme_apply(self):
+        if self.comboBox_icons_theme.currentText() == self.system_default_theme_translated['System default']:
+            self.settings.setValue('IconsTheme', 'System default')
+        else:
+            self.settings.setValue('IconsTheme', self.comboBox_icons_theme.currentText())
+
     def bold(self, state):
         self.bold_state = state
         self.bold_changed = True
@@ -513,17 +741,25 @@ class MeteoSettings(QDialog):
             bold = 'False'
         self.settings.setValue('Bold', str(bold))
 
-    def beaufort(self, state):
-        self.bft_state = state
-        self.bft_changed = True
+    def start_minimized(self, state):
+        self.start_minimized_state = state
+        self.start_minimized_changed = True
         self.buttonBox.button(QDialogButtonBox.Apply).setEnabled(True)
 
-    def beaufort_apply(self):
-        if self.bft_state == 2:
-            bft = 'True'
+    def start_minimized_apply(self):
+        if self.start_minimized_state == 2:
+            start_minimized = 'True'
         else:
-            bft = 'False'
-        self.settings.setValue('Beaufort', str(bft))
+            start_minimized = 'False'
+        self.settings.setValue('StartMinimized', start_minimized)
+
+    def logging_set(self):
+        self.buttonBox.button(QDialogButtonBox.Apply).setEnabled(True)
+        self.logging_changed = True
+
+    def logging_level_apply(self):
+        level = self.logging_level_combo.currentText()
+        self.settings.setValue('Logging/Level', level)
 
     def proxy(self, state):
         self.buttonBox.button(QDialogButtonBox.Apply).setEnabled(True)
@@ -613,6 +849,13 @@ class MeteoSettings(QDialog):
             ]
             self.settings.setValue('Unit', setUnit[0])
             logging.debug('Write ' + 'Unit ' + str(setUnit[0]))
+        if self.wind_unit_changed:
+            wind = self.wind_unit_combo.currentText()
+            setWind = [
+                key for key, value in self.wind_unit_dico.items() if value == wind
+            ]
+            logging.debug('Write ' + 'Wind_unit ' + str(setWind[0]))
+            self.settings.setValue('Wind_unit', str(setWind[0]))
         if self.temp_decimal_changed:
             decimal = self.temp_decimal_combo.currentText()
             decimal_bool_str = 'False'
@@ -624,12 +867,18 @@ class MeteoSettings(QDialog):
             self.notifier_apply()
         if self.tray_changed:
             self.tray_apply()
+        if self.toggle_tray_spinbox_changed:
+            self.toggle_tray_interval_apply()
         if self.fontsize_changed:
             self.fontsize_apply()
         if self.bold_changed:
             self.bold_apply()
-        if self.bft_changed:
-            self.beaufort_apply()
+        if self.comboBox_icons_theme_changed:
+            self.system_icontheme_apply()
+        if self.start_minimized_changed:
+            self.start_minimized_apply()
+        if self.logging_changed:
+            self.logging_level_apply()
         proxy_url = self.settings.value('Proxy_url') or ''
         if proxy_url == '':
             self.proxy_bool = False
